#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 persistent-mysql
version:              2.13.1.5
visibility:           public
id:                   persistent-mysql-2.13.1.5-IJ2qYk9fx9cDwk0Bky8pkY
key:                  persistent-mysql-2.13.1.5-IJ2qYk9fx9cDwk0Bky8pkY
license:              MIT
maintainer:           Felipe Lessa <felipe.lessa@gmail.com>
author:               Felipe Lessa <felipe.lessa@gmail.com>, Michael Snoyman
stability:            Stable
homepage:             http://www.yesodweb.com/book/persistent
synopsis:
    Backend for the persistent library using MySQL database server.

description:
    This package contains a backend for persistent using the
    MySQL database server.  Internally it uses the @mysql-simple@
    and @mysql@ packages in order to access the database.

    This package supports only MySQL 5.1 and above.  However, it
    has been tested only on MySQL 5.5.
    Only the InnoDB storage engine is officially supported.

    Known problems:

    * This package does not support statements inside other
    statements.

category:             Database, Yesod
abi:                  4c902490e2022d85e0abdeefb8e9c507
exposed:              True
exposed-modules:      Database.Persist.MySQL
import-dirs:          /usr/lib/ghc-9.6.6/site-local/persistent-mysql-2.13.1.5
library-dirs:         /usr/lib/ghc-9.6.6/site-local/persistent-mysql-2.13.1.5
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/persistent-mysql-2.13.1.5
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-persistent-mysql
hs-libraries:         HSpersistent-mysql-2.13.1.5-IJ2qYk9fx9cDwk0Bky8pkY
depends:
    aeson-2.2.2.0-HX3VmpxSu7MBeXlY03a2B0 base-4.18.2.1
    blaze-builder-0.4.4.1-JWxRMZVa4pgEH0D0I4oEQq bytestring-0.11.5.3
    conduit-1.3.6.1-EmA1TJONA2cErpLghbE74P containers-0.6.7
    monad-logger-0.3.42-A5DJ2f0YH2kKVbhsHUA7Rk
    mysql-0.2.1-5XCLlueUlfk8j8MvRuiqjY
    mysql-simple-0.4.9-58gEINKZFIqLYlGe65Cvw0
    persistent-2.14.5.2-4aAqGYQjW9n2dtsW58zyAj
    resource-pool-0.2.3.2-582cyGnophbeVnVczKtgv
    resourcet-1.2.6-6UHT6wOZljkBsLcdnEKCgw text-2.0.2
    transformers-0.6.1.0 unliftio-core-0.2.1.0-6sOpIonHj8t5wIbPhWbPHY

haddock-interfaces:
    /usr/share/doc/haskell-persistent-mysql/html/persistent-mysql.haddock

haddock-html:         /usr/share/doc/haskell-persistent-mysql/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

